screenCaptureExceptionSourceNotSpecified constant
int
const screenCaptureExceptionSourceNotSpecified
Before starting screen capture, you need to call setVideoSource, setAudioSource to specify the video and audio source ScreenCapture.
Implementation
static const int screenCaptureExceptionSourceNotSpecified = 300010009;