onAudioVADStateUpdate method
void
onAudioVADStateUpdate(
- ZegoAudioVADStableStateMonitorType type,
- ZegoAudioVADType state
Callback for audio VAD stable state update.
Available since: 2.14.0
Description: Callback for audio VAD stable state update.
When to trigger: the startAudioVADStableStateMonitor function must be called to start the audio VAD monitor and you must be in a state where it is publishing the audio and video stream or be in startPreview state.
Restrictions: The callback notification period is 3 seconds.
Related APIs: startAudioVADStableStateMonitor, stopAudioVADStableStateMonitor.
typeaudio VAD monitor typestateVAD result
Implementation
void onAudioVADStateUpdate(
ZegoAudioVADStableStateMonitorType type,
ZegoAudioVADType state,
) {}